Index: uspace/lib/libc/generic/vfs/vfs.c
===================================================================
--- uspace/lib/libc/generic/vfs/vfs.c	(revision 6408be36c6763b9e0ae86d2f2f07dbc9247e741e)
+++ uspace/lib/libc/generic/vfs/vfs.c	(revision 4198f9c3ae7988eea2c8a649c01af1be31ded05d)
@@ -138,5 +138,5 @@
 	vfs_connect();
 	
-	req = async_send_2(vfs_phone, VFS_MOUNT, dev_handle, flags, NULL);
+	req = async_send_2(vfs_phone, VFS_IN_MOUNT, dev_handle, flags, NULL);
 	rc = ipc_data_write_start(vfs_phone, (void *) mpa, mpa_size);
 	if (rc != EOK) {
@@ -199,5 +199,5 @@
 	vfs_connect();
 	
-	req = async_send_3(vfs_phone, VFS_OPEN, lflag, oflag, 0, &answer);
+	req = async_send_3(vfs_phone, VFS_IN_OPEN, lflag, oflag, 0, &answer);
 	rc = ipc_data_write_start(vfs_phone, pa, pa_size);
 	if (rc != EOK) {
@@ -231,5 +231,5 @@
 	
 	ipc_call_t answer;
-	aid_t req = async_send_4(vfs_phone, VFS_OPEN_NODE, node->fs_handle,
+	aid_t req = async_send_4(vfs_phone, VFS_IN_OPEN_NODE, node->fs_handle,
 	    node->dev_handle, node->index, oflag, &answer);
 	
@@ -253,5 +253,5 @@
 	vfs_connect();
 	
-	rc = async_req_1_0(vfs_phone, VFS_CLOSE, fildes);
+	rc = async_req_1_0(vfs_phone, VFS_IN_CLOSE, fildes);
 	
 	async_serialize_end();
@@ -271,5 +271,5 @@
 	vfs_connect();
 	
-	req = async_send_1(vfs_phone, VFS_READ, fildes, &answer);
+	req = async_send_1(vfs_phone, VFS_IN_READ, fildes, &answer);
 	rc = ipc_data_read_start(vfs_phone, (void *)buf, nbyte);
 	if (rc != EOK) {
@@ -298,5 +298,5 @@
 	vfs_connect();
 	
-	req = async_send_1(vfs_phone, VFS_WRITE, fildes, &answer);
+	req = async_send_1(vfs_phone, VFS_IN_WRITE, fildes, &answer);
 	rc = ipc_data_write_start(vfs_phone, (void *)buf, nbyte);
 	if (rc != EOK) {
@@ -322,5 +322,5 @@
 	
 	ipcarg_t device;
-	ipcarg_t rc = async_req_1_1(vfs_phone, VFS_DEVICE, fildes, &device);
+	ipcarg_t rc = async_req_1_1(vfs_phone, VFS_IN_DEVICE, fildes, &device);
 	
 	async_serialize_end();
@@ -342,5 +342,5 @@
 	ipcarg_t dev_handle;
 	ipcarg_t index;
-	ipcarg_t rc = async_req_1_3(vfs_phone, VFS_NODE, fildes, &fs_handle,
+	ipcarg_t rc = async_req_1_3(vfs_phone, VFS_IN_NODE, fildes, &fs_handle,
 	    &dev_handle, &index);
 	
@@ -363,5 +363,5 @@
 	vfs_connect();
 	
-	ipcarg_t rc = async_req_1_0(vfs_phone, VFS_SYNC, fildes);
+	ipcarg_t rc = async_req_1_0(vfs_phone, VFS_IN_SYNC, fildes);
 	
 	async_serialize_end();
@@ -380,5 +380,5 @@
 	
 	ipcarg_t newoffs;
-	rc = async_req_3_1(vfs_phone, VFS_SEEK, fildes, offset, whence,
+	rc = async_req_3_1(vfs_phone, VFS_IN_SEEK, fildes, offset, whence,
 	    &newoffs);
 
@@ -400,5 +400,5 @@
 	vfs_connect();
 	
-	rc = async_req_2_0(vfs_phone, VFS_TRUNCATE, fildes, length);
+	rc = async_req_2_0(vfs_phone, VFS_IN_TRUNCATE, fildes, length);
 	async_serialize_end();
 	futex_up(&vfs_phone_futex);
@@ -453,5 +453,5 @@
 	vfs_connect();
 	
-	req = async_send_1(vfs_phone, VFS_MKDIR, mode, NULL);
+	req = async_send_1(vfs_phone, VFS_IN_MKDIR, mode, NULL);
 	rc = ipc_data_write_start(vfs_phone, pa, pa_size);
 	if (rc != EOK) {
@@ -483,5 +483,5 @@
 	vfs_connect();
 	
-	req = async_send_0(vfs_phone, VFS_UNLINK, NULL);
+	req = async_send_0(vfs_phone, VFS_IN_UNLINK, NULL);
 	rc = ipc_data_write_start(vfs_phone, pa, pa_size);
 	if (rc != EOK) {
@@ -530,5 +530,5 @@
 	vfs_connect();
 	
-	req = async_send_0(vfs_phone, VFS_RENAME, NULL);
+	req = async_send_0(vfs_phone, VFS_IN_RENAME, NULL);
 	rc = ipc_data_write_start(vfs_phone, olda, olda_size);
 	if (rc != EOK) {
Index: uspace/lib/libc/include/ipc/console.h
===================================================================
--- uspace/lib/libc/include/ipc/console.h	(revision 6408be36c6763b9e0ae86d2f2f07dbc9247e741e)
+++ uspace/lib/libc/include/ipc/console.h	(revision 4198f9c3ae7988eea2c8a649c01af1be31ded05d)
@@ -40,5 +40,5 @@
 
 typedef enum {
-	CONSOLE_GET_SIZE = VFS_LAST_SRV,
+	CONSOLE_GET_SIZE = VFS_OUT_LAST,
 	CONSOLE_GET_EVENT,
 	CONSOLE_GOTO,
Index: uspace/lib/libc/include/ipc/vfs.h
===================================================================
--- uspace/lib/libc/include/ipc/vfs.h	(revision 6408be36c6763b9e0ae86d2f2f07dbc9247e741e)
+++ uspace/lib/libc/include/ipc/vfs.h	(revision 4198f9c3ae7988eea2c8a649c01af1be31ded05d)
@@ -58,33 +58,37 @@
 
 typedef enum {
-	VFS_OPEN_NODE = IPC_FIRST_USER_METHOD,
-	VFS_READ,
-	VFS_WRITE,
-	VFS_TRUNCATE,
-	VFS_MOUNT,
-	VFS_UNMOUNT,
-	VFS_DEVICE,
-	VFS_SYNC,
-	VFS_CLOSE,
-	VFS_LAST_CMN  /* keep this the last member of this enum */
-} vfs_request_cmn_t;
+	VFS_IN_OPEN = IPC_FIRST_USER_METHOD,
+	VFS_IN_OPEN_NODE,
+	VFS_IN_READ,
+	VFS_IN_WRITE,
+	VFS_IN_SEEK,
+	VFS_IN_TRUNCATE,
+	VFS_IN_CLOSE,
+	VFS_IN_MOUNT,
+	VFS_IN_UNMOUNT,
+	VFS_IN_DEVICE,
+	VFS_IN_SYNC,
+	VFS_IN_REGISTER,
+	VFS_IN_MKDIR,
+	VFS_IN_UNLINK,
+	VFS_IN_RENAME,
+	VFS_IN_NODE
+} vfs_in_request_t;
 
 typedef enum {
-	VFS_LOOKUP = VFS_LAST_CMN,
-	VFS_MOUNTED,
-	VFS_DESTROY,
-	VFS_LAST_CLNT  /* keep this the last member of this enum */
-} vfs_request_clnt_t;
-
-typedef enum {
-	VFS_REGISTER = VFS_LAST_CMN,
-	VFS_OPEN,
-	VFS_SEEK,
-	VFS_MKDIR,
-	VFS_UNLINK,
-	VFS_RENAME,
-	VFS_NODE,
-	VFS_LAST_SRV  /* keep this the last member of this enum */
-} vfs_request_srv_t;
+	VFS_OUT_OPEN_NODE = IPC_FIRST_USER_METHOD,
+	VFS_OUT_READ,
+	VFS_OUT_WRITE,
+	VFS_OUT_TRUNCATE,
+	VFS_OUT_CLOSE,
+	VFS_OUT_MOUNT,
+	VFS_OUT_MOUNTED,
+	VFS_OUT_UNMOUNT,
+	VFS_OUT_DEVICE,
+	VFS_OUT_SYNC,
+	VFS_OUT_LOOKUP,
+	VFS_OUT_DESTROY,
+	VFS_OUT_LAST
+} vfs_out_request_t;
 
 /*
Index: uspace/lib/libfs/libfs.c
===================================================================
--- uspace/lib/libfs/libfs.c	(revision 6408be36c6763b9e0ae86d2f2f07dbc9247e741e)
+++ uspace/lib/libfs/libfs.c	(revision 4198f9c3ae7988eea2c8a649c01af1be31ded05d)
@@ -70,5 +70,5 @@
 	 */
 	ipc_call_t answer;
-	aid_t req = async_send_0(vfs_phone, VFS_REGISTER, &answer);
+	aid_t req = async_send_0(vfs_phone, VFS_IN_REGISTER, &answer);
 
 	/*
@@ -105,5 +105,5 @@
 	 
 	/*
-	 * Pick up the answer for the request to the VFS_REQUEST call.
+	 * Pick up the answer for the request to the VFS_IN_REQUEST call.
 	 */
 	async_wait_for(req, NULL);
@@ -187,5 +187,5 @@
 	
 	ipc_call_t answer;
-	aid_t msg = async_send_1(mountee_phone, VFS_MOUNTED, mr_dev_handle,
+	aid_t msg = async_send_1(mountee_phone, VFS_OUT_MOUNTED, mr_dev_handle,
 	    &answer);
 	ipc_forward_fast(callid, mountee_phone, 0, 0, 0, IPC_FF_ROUTE_FROM_ME);
@@ -214,6 +214,6 @@
  * @param fs_handle File system handle of the file system where to perform
  *                  the lookup.
  * @param rid       Request ID of the VFS_LOOKUP request.
  * @param request   VFS_LOOKUP request data itself.
  *
  */
@@ -238,5 +238,5 @@
 
 	if (cur->mp_data.mp_active) {
-		ipc_forward_slow(rid, cur->mp_data.phone, VFS_LOOKUP,
+		ipc_forward_slow(rid, cur->mp_data.phone, VFS_OUT_LOOKUP,
 		    next, last, cur->mp_data.dev_handle, lflag, index,
 		    IPC_FF_ROUTE_FROM_ME);
@@ -273,7 +273,7 @@
 				next--;
 				
-			ipc_forward_slow(rid, tmp->mp_data.phone, VFS_LOOKUP,
-			    next, last, tmp->mp_data.dev_handle, lflag, index,
-			    IPC_FF_ROUTE_FROM_ME);
+			ipc_forward_slow(rid, tmp->mp_data.phone,
+			    VFS_OUT_LOOKUP, next, last, tmp->mp_data.dev_handle,
+			    lflag, index, IPC_FF_ROUTE_FROM_ME);
 			ops->node_put(cur);
 			ops->node_put(tmp);
@@ -433,6 +433,6 @@
  * @param ops       libfs operations structure with function pointers to
  *                  file system implementation
- * @param rid       Request ID of the VFS_OPEN_NODE request.
- * @param request   VFS_OPEN_NODE request data itself.
+ * @param rid       Request ID of the VFS_OUT_OPEN_NODE request.
+ * @param request   VFS_OUT_OPEN_NODE request data itself.
  *
  */
@@ -214,6 +214,6 @@
  * @param fs_handle File system handle of the file system where to perform
  *                  the lookup.
- * @param rid       Request ID of the VFS_LOOKUP request.
- * @param request   VFS_LOOKUP request data itself.
+ * @param rid       Request ID of the VFS_OUT_LOOKUP request.
+ * @param request   VFS_OUT_LOOKUP request data itself.
  *
  */
